# hyperstack
Leverage the Infrahub API and Hyperstack platform to easily create, manage, and scale powerful GPU virtual machines and their associated resources. 

Access this SDK to automate the deployment of your workloads and streamline your infrastructure management.

To contribute, please raise an issue with a bug report, feature request, feedback, or general inquiry.

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0
- Package version: 0.1.23
- Generator version: 7.9.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.7+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/NexGenCloud/hyperstack-sdk-python.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/NexGenCloud/hyperstack-sdk-python.git`)

Then import the package:
```python
import hyperstack
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import hyperstack
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import hyperstack
from hyperstack.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://infrahub-api.nexgencloud.com/v1
# See configuration.py for a list of all supported configuration parameters.
configuration = hyperstack.Configuration(
    host = "https://infrahub-api.nexgencloud.com/v1"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: apiKey
configuration.api_key['apiKey'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['apiKey'] = 'Bearer'

# Configure API key authorization: accessToken
configuration.api_key['accessToken'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['accessToken'] = 'Bearer'


# Enter a context with an instance of the API client
with hyperstack.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = hyperstack.CalculateApi(api_client)
    resource_type = 'resource_type_example' # str | 
    id = 56 # int | 

    try:
        # Retrieve Billing Rate for Resource
        api_response = api_instance.retrieve_billing_rate_for_resource(resource_type, id)
        print("The response of CalculateApi->retrieve_billing_rate_for_resource:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling CalculateApi->retrieve_billing_rate_for_resource: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://infrahub-api.nexgencloud.com/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*CalculateApi* | [**retrieve_billing_rate_for_resource**](docs/CalculateApi.md#retrieve_billing_rate_for_resource) | **GET** /pricebook/calculate/resource/{resource_type}/{id} | Retrieve Billing Rate for Resource
*CustomerContractApi* | [**list_contracts**](docs/CustomerContractApi.md#list_contracts) | **GET** /pricebook/contracts | List Contracts
*CustomerContractApi* | [**retrieve_contract_details**](docs/CustomerContractApi.md#retrieve_contract_details) | **GET** /pricebook/contracts/{contract_id} | Retrieve Contract Details
*CustomerContractApi* | [**retrieve_gpu_allocation_graph_for_contract**](docs/CustomerContractApi.md#retrieve_gpu_allocation_graph_for_contract) | **GET** /pricebook/contracts/{contract_id}/gpu_allocation_graph | Retrieve GPU Allocation Graph for Contract
*PricebookApi* | [**retrive_pricebook**](docs/PricebookApi.md#retrive_pricebook) | **GET** /pricebook | 
*SnapshotsApi* | [**create_an_image_from_a_snapshot**](docs/SnapshotsApi.md#create_an_image_from_a_snapshot) | **POST** /core/snapshots/{snapshot_id}/image | Create an image from a snapshot
*SnapshotsApi* | [**delete_snapshot**](docs/SnapshotsApi.md#delete_snapshot) | **DELETE** /core/snapshots/{id} | Delete snapshot
*SnapshotsApi* | [**fetch_snapshot_name_availability**](docs/SnapshotsApi.md#fetch_snapshot_name_availability) | **GET** /core/snapshots/name-availability/{name} | Fetch snapshot name availability
*SnapshotsApi* | [**restore_a_snapshot**](docs/SnapshotsApi.md#restore_a_snapshot) | **POST** /core/snapshots/{id}/restore | Restore a snapshot
*SnapshotsApi* | [**retrieve_a_snapshot**](docs/SnapshotsApi.md#retrieve_a_snapshot) | **GET** /core/snapshots/{id} | Retrieve a snapshot
*SnapshotsApi* | [**retrieve_list_of_snapshots_with_pagination**](docs/SnapshotsApi.md#retrieve_list_of_snapshots_with_pagination) | **GET** /core/snapshots | Retrieve list of snapshots with pagination
*AliveApi* | [**get_alive**](docs/AliveApi.md#get_alive) | **GET** /billing/alive | GET: Alive
*ApiKeyApi* | [**delete_api_key**](docs/ApiKeyApi.md#delete_api_key) | **DELETE** /api-key/{api_key_id} | Delete API Key
*ApiKeyApi* | [**generate_api_key**](docs/ApiKeyApi.md#generate_api_key) | **POST** /api-key/generate | Generate API Key
*ApiKeyApi* | [**retrieve_api_keys**](docs/ApiKeyApi.md#retrieve_api_keys) | **GET** /api-key | Retrieve API Keys
*ApiKeyApi* | [**update_api_key**](docs/ApiKeyApi.md#update_api_key) | **PUT** /api-key/{api_key_id} | Update API Key
*AssigningMemberRoleApi* | [**assign_rbac_role**](docs/AssigningMemberRoleApi.md#assign_rbac_role) | **PUT** /auth/users/{user_id}/assign-roles | Assign RBAC Role
*AssigningMemberRoleApi* | [**remove_rbac_role_from_user**](docs/AssigningMemberRoleApi.md#remove_rbac_role_from_user) | **DELETE** /auth/users/{user_id}/roles | Remove RBAC Role From User
*AuthApi* | [**retrieve_authenticated_user_details**](docs/AuthApi.md#retrieve_authenticated_user_details) | **GET** /auth/me | Retrieve Authenticated User Details
*BillingApi* | [**get_all_thresholds_for_organization**](docs/BillingApi.md#get_all_thresholds_for_organization) | **GET** /billing/billing/threshold | GET: All Thresholds for Organization
*BillingApi* | [**get_billing_usage**](docs/BillingApi.md#get_billing_usage) | **GET** /billing/billing/usage | GET: Billing usage
*BillingApi* | [**get_last_day_cost**](docs/BillingApi.md#get_last_day_cost) | **GET** /billing/billing/last-day-cost | GET: Last Day Cost
*BillingApi* | [**retrieve_billing_history_for_a_specific_billing_cycle**](docs/BillingApi.md#retrieve_billing_history_for_a_specific_billing_cycle) | **GET** /billing/billing/history | Retrieve Billing History for a specific Billing Cycle
*BillingApi* | [**retrieve_billing_history_of_a_specific_virtual_machine_for_a_specific_billing_cycle**](docs/BillingApi.md#retrieve_billing_history_of_a_specific_virtual_machine_for_a_specific_billing_cycle) | **GET** /billing/billing/history/virtual-machine/{vm_id} | Retrieve Billing History of a Specific Virtual Machine for a specific Billing Cycle
*BillingApi* | [**retrieve_billing_history_of_a_specific_volume_for_a_specific_billing_cycle**](docs/BillingApi.md#retrieve_billing_history_of_a_specific_volume_for_a_specific_billing_cycle) | **GET** /billing/billing/history/snapshot/{snapshot_id} | Retrieve Billing History of a Specific Volume for a specific Billing Cycle
*BillingApi* | [**retrieve_billing_history_of_a_specific_volume_for_a_specific_billing_cycle_0**](docs/BillingApi.md#retrieve_billing_history_of_a_specific_volume_for_a_specific_billing_cycle_0) | **GET** /billing/billing/history/volume/{volume_id} | Retrieve Billing History of a Specific Volume for a specific Billing Cycle
*BillingApi* | [**retrieve_billing_history_of_contract_for_a_specific_billing_cycle**](docs/BillingApi.md#retrieve_billing_history_of_contract_for_a_specific_billing_cycle) | **GET** /billing/billing/history/contract | Retrieve Billing History of Contract for a specific Billing Cycle
*BillingApi* | [**retrieve_billing_history_of_snapshot_for_a_specific_billing_cycle**](docs/BillingApi.md#retrieve_billing_history_of_snapshot_for_a_specific_billing_cycle) | **GET** /billing/billing/history/snapshot | Retrieve Billing History of Snapshot for a specific Billing Cycle
*BillingApi* | [**retrieve_billing_history_of_virtual_machine_for_a_specific_billing_cycle**](docs/BillingApi.md#retrieve_billing_history_of_virtual_machine_for_a_specific_billing_cycle) | **GET** /billing/billing/history/virtual-machine | Retrieve Billing History of Virtual Machine for a specific Billing Cycle
*BillingApi* | [**retrieve_billing_history_of_volume_for_a_specific_billing_cycle**](docs/BillingApi.md#retrieve_billing_history_of_volume_for_a_specific_billing_cycle) | **GET** /billing/billing/history/volume | Retrieve Billing History of Volume for a specific Billing Cycle
*BillingApi* | [**retrieve_hourly_cost_datapoints_of_a_specific_snapshot_for_a_specific_billing_cycle**](docs/BillingApi.md#retrieve_hourly_cost_datapoints_of_a_specific_snapshot_for_a_specific_billing_cycle) | **GET** /billing/billing/history/snapshot/{snapshot_id}/graph | Retrieve hourly cost datapoints of a Specific Snapshot for a specific billing cycle
*BillingApi* | [**retrieve_hourly_cost_datapoints_of_a_specific_virtual_machine_for_a_specific_billing_cycle**](docs/BillingApi.md#retrieve_hourly_cost_datapoints_of_a_specific_virtual_machine_for_a_specific_billing_cycle) | **GET** /billing/billing/history/virtual-machine/{vm_id}/graph | Retrieve hourly cost datapoints of a Specific Virtual Machine for a specific billing cycle
*BillingApi* | [**retrieve_hourly_cost_datapoints_of_a_specific_volume_for_a_specific_billing_cycle**](docs/BillingApi.md#retrieve_hourly_cost_datapoints_of_a_specific_volume_for_a_specific_billing_cycle) | **GET** /billing/billing/history/volume/{volume_id}/graph | Retrieve hourly cost datapoints of a Specific Volume for a specific billing cycle
*BillingApi* | [**retrieve_sub_resources_historical_cost_datapoints_of_a_virtual**](docs/BillingApi.md#retrieve_sub_resources_historical_cost_datapoints_of_a_virtual) | **GET** /billing/billing/virtual-machine/{vm_id}/sub-resource/graph | Retrieve Sub-Resources Historical Cost datapoints of a Virtual
*BillingApi* | [**retrieve_total_costs_and_non_discount_costs_for_sub_resources**](docs/BillingApi.md#retrieve_total_costs_and_non_discount_costs_for_sub_resources) | **GET** /billing/billing/virtual-machine/{vm_id}/sub-resource | Retrieve Total Costs and Non Discount Costs for Sub Resources
*BillingApi* | [**retrieve_vm_billing_events_history**](docs/BillingApi.md#retrieve_vm_billing_events_history) | **GET** /billing/billing/virtual-machine/{vm_id}/billing-events | Retrieve VM billing events history
*BillingApi* | [**retrieve_volume_billing_events_history**](docs/BillingApi.md#retrieve_volume_billing_events_history) | **GET** /billing/billing/volume/{volume_id}/billing-events | Retrieve Volume billing events history
*BillingApi* | [**update_subscribe_or_unsubscribe_notification_threshold**](docs/BillingApi.md#update_subscribe_or_unsubscribe_notification_threshold) | **PUT** /billing/billing/threshold/{threshold_id} | Update: Subscribe or Unsubscribe Notification Threshold
*CallbacksApi* | [**attach_callback_to_virtual_machine**](docs/CallbacksApi.md#attach_callback_to_virtual_machine) | **POST** /core/virtual-machines/{id}/attach-callback | Attach callback to virtual machine
*CallbacksApi* | [**attach_callback_to_volume**](docs/CallbacksApi.md#attach_callback_to_volume) | **POST** /core/volumes/{id}/attach-callback | Attach callback to volume
*CallbacksApi* | [**delete_virtual_machine_callback**](docs/CallbacksApi.md#delete_virtual_machine_callback) | **DELETE** /core/virtual-machines/{id}/delete-callback | Delete virtual machine callback
*CallbacksApi* | [**delete_volume_callback**](docs/CallbacksApi.md#delete_volume_callback) | **DELETE** /core/volumes/{id}/delete-callback | Delete volume callback
*CallbacksApi* | [**update_virtual_machine_callback**](docs/CallbacksApi.md#update_virtual_machine_callback) | **PUT** /core/virtual-machines/{id}/update-callback | Update virtual machine callback
*CallbacksApi* | [**update_volume_callback**](docs/CallbacksApi.md#update_volume_callback) | **PUT** /core/volumes/{id}/update-callback | Update volume callback
*ClusterEventsApi* | [**fetch_all_of_a_cluster_events**](docs/ClusterEventsApi.md#fetch_all_of_a_cluster_events) | **GET** /core/clusters/{cluster_id}/events | Fetch all of a cluster events
*ClustersApi* | [**create_cluster**](docs/ClustersApi.md#create_cluster) | **POST** /core/clusters | Create Cluster
*ClustersApi* | [**delete_a_cluster**](docs/ClustersApi.md#delete_a_cluster) | **DELETE** /core/clusters/{id} | Delete a cluster
*ClustersApi* | [**fetch_cluster_name_availability**](docs/ClustersApi.md#fetch_cluster_name_availability) | **GET** /core/clusters/name-availability/{name} | Fetch cluster name availability
*ClustersApi* | [**get_cluster_versions**](docs/ClustersApi.md#get_cluster_versions) | **GET** /core/clusters/versions | GET Cluster Versions
*ClustersApi* | [**getting_cluster_detail**](docs/ClustersApi.md#getting_cluster_detail) | **GET** /core/clusters/{id} | Getting Cluster Detail
*ClustersApi* | [**list_clusters**](docs/ClustersApi.md#list_clusters) | **GET** /core/clusters | List Clusters
*ComplianceApi* | [**create_compliance**](docs/ComplianceApi.md#create_compliance) | **POST** /core/compliance | Create compliance
*ComplianceApi* | [**delete_a_compliance**](docs/ComplianceApi.md#delete_a_compliance) | **DELETE** /core/compliance/{gpu_model} | Delete a compliance
*ComplianceApi* | [**retrieve_gpu_compliance**](docs/ComplianceApi.md#retrieve_gpu_compliance) | **GET** /core/compliance | Retrieve GPU compliance
*ComplianceApi* | [**update_a_compliance**](docs/ComplianceApi.md#update_a_compliance) | **PUT** /core/compliance | Update a compliance
*CreditApi* | [**get_view_credit_and_threshold**](docs/CreditApi.md#get_view_credit_and_threshold) | **GET** /billing/user-credit/credit | GET: View credit and threshold
*DashboardApi* | [**retrieve_dashboard**](docs/DashboardApi.md#retrieve_dashboard) | **GET** /core/dashboard | Retrieve Dashboard
*DeploymentApi* | [**delete_deployment**](docs/DeploymentApi.md#delete_deployment) | **DELETE** /core/marketplace/deployments/{id} | Delete Deployment
*DeploymentApi* | [**details_of_deployment_by_id**](docs/DeploymentApi.md#details_of_deployment_by_id) | **GET** /core/marketplace/deployments/{id} | Details of Deployment by ID
*DeploymentApi* | [**list_deployments**](docs/DeploymentApi.md#list_deployments) | **GET** /core/marketplace/deployments | List Deployments
*DeploymentApi* | [**start_deployment**](docs/DeploymentApi.md#start_deployment) | **POST** /core/marketplace/deployments | Start Deployment
*EnvironmentApi* | [**create_environment**](docs/EnvironmentApi.md#create_environment) | **POST** /core/environments | Create environment
*EnvironmentApi* | [**delete_environment**](docs/EnvironmentApi.md#delete_environment) | **DELETE** /core/environments/{id} | Delete environment
*EnvironmentApi* | [**list_environments**](docs/EnvironmentApi.md#list_environments) | **GET** /core/environments | List environments
*EnvironmentApi* | [**retrieve_environment**](docs/EnvironmentApi.md#retrieve_environment) | **GET** /core/environments/{id} | Retrieve environment
*EnvironmentApi* | [**update_environment**](docs/EnvironmentApi.md#update_environment) | **PUT** /core/environments/{id} | Update environment
*FirewallAttachmentApi* | [**attach_firewalls_to_vms**](docs/FirewallAttachmentApi.md#attach_firewalls_to_vms) | **POST** /core/firewalls/{firewall_id}/update-attachments | Attach Firewalls to VMs
*FirewallsApi* | [**add_firewall_rule_to_firewall**](docs/FirewallsApi.md#add_firewall_rule_to_firewall) | **POST** /core/firewalls/{firewall_id}/firewall-rules | Add firewall rule to firewall
*FirewallsApi* | [**create_firewall**](docs/FirewallsApi.md#create_firewall) | **POST** /core/firewalls | Create firewall
*FirewallsApi* | [**delete_firewall**](docs/FirewallsApi.md#delete_firewall) | **DELETE** /core/firewalls/{id} | Delete firewall
*FirewallsApi* | [**delete_firewall_rules_from_firewall**](docs/FirewallsApi.md#delete_firewall_rules_from_firewall) | **DELETE** /core/firewalls/{firewall_id}/firewall-rules/{firewall_rule_id} | Delete firewall rules from firewall
*FirewallsApi* | [**list_firewalls**](docs/FirewallsApi.md#list_firewalls) | **GET** /core/firewalls | List firewalls
*FirewallsApi* | [**retrieve_firewall_details**](docs/FirewallsApi.md#retrieve_firewall_details) | **GET** /core/firewalls/{id} | Retrieve firewall details
*FlavorApi* | [**list_flavors**](docs/FlavorApi.md#list_flavors) | **GET** /core/flavors | List Flavors
*FloatingIpApi* | [**attach_public_ip_to_virtual_machine**](docs/FloatingIpApi.md#attach_public_ip_to_virtual_machine) | **POST** /core/virtual-machines/{id}/attach-floatingip | Attach public IP to virtual machine
*FloatingIpApi* | [**detach_public_ip_from_virtual_machine**](docs/FloatingIpApi.md#detach_public_ip_from_virtual_machine) | **POST** /core/virtual-machines/{id}/detach-floatingip | Detach public IP from virtual machine
*GpuApi* | [**list_gpus**](docs/GpuApi.md#list_gpus) | **GET** /core/gpus | List GPUs
*ImageApi* | [**delete_an_image**](docs/ImageApi.md#delete_an_image) | **DELETE** /core/images/{id} | Delete an image
*ImageApi* | [**fetch_name_availability_for_images**](docs/ImageApi.md#fetch_name_availability_for_images) | **GET** /core/image/name-availability/{name} | Fetch name availability for Images
*ImageApi* | [**get_private_image_details**](docs/ImageApi.md#get_private_image_details) | **GET** /core/images/{id} | Get Private Image Details
*ImageApi* | [**list_images**](docs/ImageApi.md#list_images) | **GET** /core/images | List Images
*InviteApi* | [**delete_invite**](docs/InviteApi.md#delete_invite) | **DELETE** /auth/invites/{id} | Delete Invite
*InviteApi* | [**invite_user_to_organization**](docs/InviteApi.md#invite_user_to_organization) | **POST** /auth/invites | Invite User to Organization
*InviteApi* | [**list_invites**](docs/InviteApi.md#list_invites) | **GET** /auth/invites | List Invites
*KeypairApi* | [**delete_key_pair**](docs/KeypairApi.md#delete_key_pair) | **DELETE** /core/keypair/{id} | Delete key pair
*KeypairApi* | [**import_key_pair**](docs/KeypairApi.md#import_key_pair) | **POST** /core/keypairs | Import key pair
*KeypairApi* | [**list_key_pairs**](docs/KeypairApi.md#list_key_pairs) | **GET** /core/keypairs | List key pairs
*KeypairApi* | [**update_key_pair_name**](docs/KeypairApi.md#update_key_pair_name) | **PUT** /core/keypair/{id} | Update key pair name
*OrganizationApi* | [**remove_organization_member**](docs/OrganizationApi.md#remove_organization_member) | **POST** /auth/organizations/remove-member | Remove Organization Member
*OrganizationApi* | [**retrieve_organization_information**](docs/OrganizationApi.md#retrieve_organization_information) | **GET** /auth/organizations | Retrieve Organization Information
*OrganizationApi* | [**update_organization_information**](docs/OrganizationApi.md#update_organization_information) | **PUT** /auth/organizations/update | Update Organization Information
*PaymentApi* | [**get_view_payment_details**](docs/PaymentApi.md#get_view_payment_details) | **GET** /billing/payment/payment-details | GET: View payment details
*PaymentApi* | [**post_initiate_payment**](docs/PaymentApi.md#post_initiate_payment) | **POST** /billing/payment/payment-initiate | POST: Initiate payment
*PermissionApi* | [**list_permissions**](docs/PermissionApi.md#list_permissions) | **GET** /auth/permissions | List Permissions
*PolicyApi* | [**list_policies**](docs/PolicyApi.md#list_policies) | **GET** /auth/policies | List Policies
*ProfileApi* | [**create_profile**](docs/ProfileApi.md#create_profile) | **POST** /core/profiles | Create profile
*ProfileApi* | [**delete_profile**](docs/ProfileApi.md#delete_profile) | **DELETE** /core/profiles/{id} | Delete profile
*ProfileApi* | [**list_profiles**](docs/ProfileApi.md#list_profiles) | **GET** /core/profiles | List profiles
*ProfileApi* | [**retrieve_profile_details**](docs/ProfileApi.md#retrieve_profile_details) | **GET** /core/profiles/{id} | Retrieve profile details
*RbacRoleApi* | [**create_rbac_role**](docs/RbacRoleApi.md#create_rbac_role) | **POST** /auth/roles | Create RBAC Role
*RbacRoleApi* | [**delete_rbac_role**](docs/RbacRoleApi.md#delete_rbac_role) | **DELETE** /auth/roles/{id} | Delete RBAC Role
*RbacRoleApi* | [**list_rbac_roles**](docs/RbacRoleApi.md#list_rbac_roles) | **GET** /auth/roles | List RBAC Roles
*RbacRoleApi* | [**retrieve_rbac_role_details**](docs/RbacRoleApi.md#retrieve_rbac_role_details) | **GET** /auth/roles/{id} | Retrieve RBAC Role Details
*RbacRoleApi* | [**update_rbac_role**](docs/RbacRoleApi.md#update_rbac_role) | **PUT** /auth/roles/{id} | Update RBAC Role
*RegionApi* | [**list_regions**](docs/RegionApi.md#list_regions) | **GET** /core/regions | List regions
*SecurityRulesApi* | [**list_firewall_rule_protocols**](docs/SecurityRulesApi.md#list_firewall_rule_protocols) | **GET** /core/sg-rules-protocols | List firewall rule protocols
*SnapshotEventsApi* | [**fetch_all_events_for_a_snapshot**](docs/SnapshotEventsApi.md#fetch_all_events_for_a_snapshot) | **GET** /core/snapshots/{snapshot_id}/events | Fetch all events for a snapshot
*StockApi* | [**retrieve_gpu_stocks**](docs/StockApi.md#retrieve_gpu_stocks) | **GET** /core/stocks | Retrieve GPU stocks
*TemplateApi* | [**create_template**](docs/TemplateApi.md#create_template) | **POST** /core/marketplace/templates | Create template
*TemplateApi* | [**delete_template**](docs/TemplateApi.md#delete_template) | **DELETE** /core/marketplace/templates/{id} | Delete template
*TemplateApi* | [**list_templates**](docs/TemplateApi.md#list_templates) | **GET** /core/marketplace/templates | List templates
*TemplateApi* | [**retrieve_template_details**](docs/TemplateApi.md#retrieve_template_details) | **GET** /core/marketplace/templates/{id} | Retrieve template details
*TemplateApi* | [**update_template**](docs/TemplateApi.md#update_template) | **PUT** /core/marketplace/templates/{id} | Update template
*UserApi* | [**get_fetch_user_info**](docs/UserApi.md#get_fetch_user_info) | **GET** /billing/user/info | GET: Fetch User Info
*UserApi* | [**post_insert_user_info**](docs/UserApi.md#post_insert_user_info) | **POST** /billing/user/info | POST: Insert user info
*UserApi* | [**put_update_user_info**](docs/UserApi.md#put_update_user_info) | **PUT** /billing/user/info | PUT: Update user info
*UserDetailChoiceApi* | [**retrieve_default_flavors_and_images**](docs/UserDetailChoiceApi.md#retrieve_default_flavors_and_images) | **GET** /core/user/resources/defaults | Retrieve Default Flavors and Images
*UserPermissionApi* | [**list_my_user_permissions**](docs/UserPermissionApi.md#list_my_user_permissions) | **GET** /auth/users/me/permissions | List My User Permissions
*UserPermissionApi* | [**list_user_permissions**](docs/UserPermissionApi.md#list_user_permissions) | **GET** /auth/users/{id}/permissions | List User Permissions
*VirtualMachineApi* | [**add_firewall_rule_to_virtual_machine**](docs/VirtualMachineApi.md#add_firewall_rule_to_virtual_machine) | **POST** /core/virtual-machines/{id}/sg-rules | Add firewall rule to virtual machine
*VirtualMachineApi* | [**attach_firewalls_to_a_virtual_machine**](docs/VirtualMachineApi.md#attach_firewalls_to_a_virtual_machine) | **POST** /core/virtual-machines/{vm_id}/attach-firewalls | Attach firewalls to a virtual machine
*VirtualMachineApi* | [**create_snapshot_from_a_virtual_machine**](docs/VirtualMachineApi.md#create_snapshot_from_a_virtual_machine) | **POST** /core/virtual-machines/{vm_id}/snapshots | Create snapshot from a virtual machine
*VirtualMachineApi* | [**create_virtual_machines**](docs/VirtualMachineApi.md#create_virtual_machines) | **POST** /core/virtual-machines | Create virtual machines
*VirtualMachineApi* | [**delete_firewall_rule_from_virtual_machine**](docs/VirtualMachineApi.md#delete_firewall_rule_from_virtual_machine) | **DELETE** /core/virtual-machines/{virtual_machine_id}/sg-rules/{sg_rule_id} | Delete firewall rule from virtual machine
*VirtualMachineApi* | [**delete_virtual_machine**](docs/VirtualMachineApi.md#delete_virtual_machine) | **DELETE** /core/virtual-machines/{id} | Delete virtual machine
*VirtualMachineApi* | [**edit_virtual_machine_labels**](docs/VirtualMachineApi.md#edit_virtual_machine_labels) | **PUT** /core/virtual-machines/{virtual_machine_id}/label | Edit virtual machine labels
*VirtualMachineApi* | [**fetch_virtual_machine_name_availability**](docs/VirtualMachineApi.md#fetch_virtual_machine_name_availability) | **GET** /core/virtual-machines/name-availability/{name} | Fetch virtual machine name availability
*VirtualMachineApi* | [**hard_reboot_virtual_machine**](docs/VirtualMachineApi.md#hard_reboot_virtual_machine) | **GET** /core/virtual-machines/{id}/hard-reboot | Hard reboot virtual machine
*VirtualMachineApi* | [**hibernate_virtual_machine**](docs/VirtualMachineApi.md#hibernate_virtual_machine) | **GET** /core/virtual-machines/{virtual_machine_id}/hibernate | Hibernate virtual machine
*VirtualMachineApi* | [**list_virtual_machines**](docs/VirtualMachineApi.md#list_virtual_machines) | **GET** /core/virtual-machines | List virtual machines
*VirtualMachineApi* | [**resize_virtual_machine**](docs/VirtualMachineApi.md#resize_virtual_machine) | **POST** /core/virtual-machines/{virtual_machine_id}/resize | Resize virtual machine
*VirtualMachineApi* | [**restore_virtual_machine_from_hibernation**](docs/VirtualMachineApi.md#restore_virtual_machine_from_hibernation) | **GET** /core/virtual-machines/{virtual_machine_id}/hibernate-restore | Restore virtual machine from hibernation
*VirtualMachineApi* | [**retrieve_virtual_machine_details**](docs/VirtualMachineApi.md#retrieve_virtual_machine_details) | **GET** /core/virtual-machines/{id} | Retrieve virtual machine details
*VirtualMachineApi* | [**retrieve_virtual_machine_performance_metrics**](docs/VirtualMachineApi.md#retrieve_virtual_machine_performance_metrics) | **GET** /core/virtual-machines/{virtual_machine_id}/metrics | Retrieve virtual machine performance metrics
*VirtualMachineApi* | [**retrieve_virtual_machines_associated_with_a_contract**](docs/VirtualMachineApi.md#retrieve_virtual_machines_associated_with_a_contract) | **GET** /core/virtual-machines/contract/{contract_id}/virtual-machines | Retrieve virtual machines associated with a contract
*VirtualMachineApi* | [**start_virtual_machine**](docs/VirtualMachineApi.md#start_virtual_machine) | **GET** /core/virtual-machines/{id}/start | Start virtual machine
*VirtualMachineApi* | [**stop_virtual_machine**](docs/VirtualMachineApi.md#stop_virtual_machine) | **GET** /core/virtual-machines/{id}/stop | Stop virtual machine
*VirtualMachineEventsApi* | [**list_virtual_machine_events**](docs/VirtualMachineEventsApi.md#list_virtual_machine_events) | **GET** /core/virtual-machines/{virtual_machine_id}/events | List virtual machine events
*VncUrlApi* | [**get_vnc_console_link**](docs/VncUrlApi.md#get_vnc_console_link) | **GET** /core/virtual-machines/{virtual_machine_id}/console/{job_id} | Get VNC Console Link
*VncUrlApi* | [**request_instance_console**](docs/VncUrlApi.md#request_instance_console) | **GET** /core/virtual-machines/{id}/request-console | Request Instance Console
*VolumeApi* | [**create_volume**](docs/VolumeApi.md#create_volume) | **POST** /core/volumes | Create volume
*VolumeApi* | [**delete_volume**](docs/VolumeApi.md#delete_volume) | **DELETE** /core/volumes/{id} | Delete volume
*VolumeApi* | [**fetch_volume_details**](docs/VolumeApi.md#fetch_volume_details) | **GET** /core/volume/{volume_id} | Fetch Volume Details
*VolumeApi* | [**fetch_volume_name_availability**](docs/VolumeApi.md#fetch_volume_name_availability) | **GET** /core/volume/name-availability/{name} | Fetch volume name availability
*VolumeApi* | [**list_volume_types**](docs/VolumeApi.md#list_volume_types) | **GET** /core/volume-types | List volume types
*VolumeApi* | [**list_volumes**](docs/VolumeApi.md#list_volumes) | **GET** /core/volumes | List volumes
*VolumeAttachmentApi* | [**attach_volumes_to_virtual_machine**](docs/VolumeAttachmentApi.md#attach_volumes_to_virtual_machine) | **POST** /core/virtual-machines/{virtual_machine_id}/attach-volumes | Attach volumes to virtual machine
*VolumeAttachmentApi* | [**detach_volumes_from_virtual_machine**](docs/VolumeAttachmentApi.md#detach_volumes_from_virtual_machine) | **POST** /core/virtual-machines/{virtual_machine_id}/detach-volumes | Detach volumes from virtual machine


## Documentation For Models

 - [AddUpdateFlavorOrganizationPayload](docs/AddUpdateFlavorOrganizationPayload.md)
 - [AddUserInfoSuccessResponseModel](docs/AddUserInfoSuccessResponseModel.md)
 - [AllocatedGPUCountGraph](docs/AllocatedGPUCountGraph.md)
 - [ApiKeyFields](docs/ApiKeyFields.md)
 - [ApiKeyVerifyFields](docs/ApiKeyVerifyFields.md)
 - [AssignRbacRolePayload](docs/AssignRbacRolePayload.md)
 - [AttachCallbackPayload](docs/AttachCallbackPayload.md)
 - [AttachCallbackResponse](docs/AttachCallbackResponse.md)
 - [AttachFirewallWithVM](docs/AttachFirewallWithVM.md)
 - [AttachFirewallsToVMPayload](docs/AttachFirewallsToVMPayload.md)
 - [AttachVolumeFields](docs/AttachVolumeFields.md)
 - [AttachVolumes](docs/AttachVolumes.md)
 - [AttachVolumesPayload](docs/AttachVolumesPayload.md)
 - [AuthGetTokenResponseModel](docs/AuthGetTokenResponseModel.md)
 - [AuthRequestLoginFields](docs/AuthRequestLoginFields.md)
 - [AuthRequestLoginResponseModel](docs/AuthRequestLoginResponseModel.md)
 - [AuthUserFields](docs/AuthUserFields.md)
 - [AuthUserInfoResponseModel](docs/AuthUserInfoResponseModel.md)
 - [BillingImmuneResourcesResponse](docs/BillingImmuneResourcesResponse.md)
 - [BillingResponse](docs/BillingResponse.md)
 - [Billingmetricesfields](docs/Billingmetricesfields.md)
 - [Billingmetricesresponse](docs/Billingmetricesresponse.md)
 - [ClusterEvents](docs/ClusterEvents.md)
 - [ClusterEventsFields](docs/ClusterEventsFields.md)
 - [ClusterFields](docs/ClusterFields.md)
 - [ClusterListResponse](docs/ClusterListResponse.md)
 - [ClusterResponse](docs/ClusterResponse.md)
 - [ClusterVersions](docs/ClusterVersions.md)
 - [CommonResponseModel](docs/CommonResponseModel.md)
 - [ComplianceFields](docs/ComplianceFields.md)
 - [ComplianceModelFields](docs/ComplianceModelFields.md)
 - [CompliancePayload](docs/CompliancePayload.md)
 - [ComplianceResponse](docs/ComplianceResponse.md)
 - [ContainerOverviewFields](docs/ContainerOverviewFields.md)
 - [Contract](docs/Contract.md)
 - [ContractBillingHistory](docs/ContractBillingHistory.md)
 - [ContractBillingHistoryResponseAttributes](docs/ContractBillingHistoryResponseAttributes.md)
 - [ContractBillingHistoryResponseModel](docs/ContractBillingHistoryResponseModel.md)
 - [ContractChangePayload](docs/ContractChangePayload.md)
 - [ContractDiscountPlanFields](docs/ContractDiscountPlanFields.md)
 - [ContractEligibleInstanceFields](docs/ContractEligibleInstanceFields.md)
 - [ContractEligibleInstancesResponse](docs/ContractEligibleInstancesResponse.md)
 - [ContractEventCreateModel](docs/ContractEventCreateModel.md)
 - [ContractGPUAllocationGraphResponse](docs/ContractGPUAllocationGraphResponse.md)
 - [ContractInstanceFields](docs/ContractInstanceFields.md)
 - [ContractInstancesResponse](docs/ContractInstancesResponse.md)
 - [ContractResourcePayload](docs/ContractResourcePayload.md)
 - [ContractlBillingHistoryResponseMetrics](docs/ContractlBillingHistoryResponseMetrics.md)
 - [CreateClusterPayload](docs/CreateClusterPayload.md)
 - [CreateContractFields](docs/CreateContractFields.md)
 - [CreateContractPayload](docs/CreateContractPayload.md)
 - [CreateDiscountResponse](docs/CreateDiscountResponse.md)
 - [CreateDiscountsPayload](docs/CreateDiscountsPayload.md)
 - [CreateEnvironment](docs/CreateEnvironment.md)
 - [CreateFirewallPayload](docs/CreateFirewallPayload.md)
 - [CreateFirewallRulePayload](docs/CreateFirewallRulePayload.md)
 - [CreateGPU](docs/CreateGPU.md)
 - [CreateImage](docs/CreateImage.md)
 - [CreateImagePayload](docs/CreateImagePayload.md)
 - [CreateInstancesPayload](docs/CreateInstancesPayload.md)
 - [CreateInstancesResponse](docs/CreateInstancesResponse.md)
 - [CreateProfilePayload](docs/CreateProfilePayload.md)
 - [CreateProfileResponse](docs/CreateProfileResponse.md)
 - [CreateSecurityRulePayload](docs/CreateSecurityRulePayload.md)
 - [CreateSnapshotPayload](docs/CreateSnapshotPayload.md)
 - [CreateSnapshotResponse](docs/CreateSnapshotResponse.md)
 - [CreateUpdateComplianceResponse](docs/CreateUpdateComplianceResponse.md)
 - [CreateUpdatePermissionPayload](docs/CreateUpdatePermissionPayload.md)
 - [CreateUpdatePermissionResponseModel](docs/CreateUpdatePermissionResponseModel.md)
 - [CreateUpdatePolicyPayload](docs/CreateUpdatePolicyPayload.md)
 - [CreateUpdatePolicyResponseModel](docs/CreateUpdatePolicyResponseModel.md)
 - [CreateUpdateRbacRolePayload](docs/CreateUpdateRbacRolePayload.md)
 - [CreateVolumePayload](docs/CreateVolumePayload.md)
 - [Creditrechargelimitfield](docs/Creditrechargelimitfield.md)
 - [Creditrechargelimitresponse](docs/Creditrechargelimitresponse.md)
 - [Creditrequestresponse](docs/Creditrequestresponse.md)
 - [Creditrequests](docs/Creditrequests.md)
 - [CustomerContractDetailResponseModel](docs/CustomerContractDetailResponseModel.md)
 - [CustomerContractFields](docs/CustomerContractFields.md)
 - [CustomerFields](docs/CustomerFields.md)
 - [CustomerPayload](docs/CustomerPayload.md)
 - [DashboardInfoResponse](docs/DashboardInfoResponse.md)
 - [Data](docs/Data.md)
 - [DeploymentFields](docs/DeploymentFields.md)
 - [DeploymentFieldsforstartdeployments](docs/DeploymentFieldsforstartdeployments.md)
 - [Deployments](docs/Deployments.md)
 - [DetachVolumes](docs/DetachVolumes.md)
 - [DetachVolumesPayload](docs/DetachVolumesPayload.md)
 - [DiscountEntityModel](docs/DiscountEntityModel.md)
 - [DiscountFields](docs/DiscountFields.md)
 - [DiscountPlanFields](docs/DiscountPlanFields.md)
 - [DiscountResourceFields](docs/DiscountResourceFields.md)
 - [DiscountResourcePayload](docs/DiscountResourcePayload.md)
 - [EditlabelofanexistingVMPayload](docs/EditlabelofanexistingVMPayload.md)
 - [Environment](docs/Environment.md)
 - [EnvironmentFeatures](docs/EnvironmentFeatures.md)
 - [EnvironmentFields](docs/EnvironmentFields.md)
 - [EnvironmentFieldsforVolume](docs/EnvironmentFieldsforVolume.md)
 - [Environments](docs/Environments.md)
 - [ErrorResponseModel](docs/ErrorResponseModel.md)
 - [ExcludeBillingPostPayload](docs/ExcludeBillingPostPayload.md)
 - [ExcludeBillingPostResponse](docs/ExcludeBillingPostResponse.md)
 - [ExportBillingDataRequest](docs/ExportBillingDataRequest.md)
 - [ExportBillingDataResponse](docs/ExportBillingDataResponse.md)
 - [FieldChange](docs/FieldChange.md)
 - [FirewallAttachmentModel](docs/FirewallAttachmentModel.md)
 - [FirewallAttachmentVMModel](docs/FirewallAttachmentVMModel.md)
 - [FirewallDetailFields](docs/FirewallDetailFields.md)
 - [FirewallDetailResponse](docs/FirewallDetailResponse.md)
 - [FirewallEnvironmentFields](docs/FirewallEnvironmentFields.md)
 - [FirewallFields](docs/FirewallFields.md)
 - [FirewallResponse](docs/FirewallResponse.md)
 - [FirewallRule](docs/FirewallRule.md)
 - [FirewallsListResponse](docs/FirewallsListResponse.md)
 - [FlavorFields](docs/FlavorFields.md)
 - [FlavorItemGetResponse](docs/FlavorItemGetResponse.md)
 - [FlavorListResponse](docs/FlavorListResponse.md)
 - [FlavorObjectFields](docs/FlavorObjectFields.md)
 - [FlavorPayload](docs/FlavorPayload.md)
 - [FlavorResponse](docs/FlavorResponse.md)
 - [FlavorVMFields](docs/FlavorVMFields.md)
 - [FlavorVMsResponse](docs/FlavorVMsResponse.md)
 - [FutureNodeModel](docs/FutureNodeModel.md)
 - [FutureNodeResponseModel](docs/FutureNodeResponseModel.md)
 - [FutureNodeStockModel](docs/FutureNodeStockModel.md)
 - [FutureNodeUpdateModel](docs/FutureNodeUpdateModel.md)
 - [FutureNodesStockModel](docs/FutureNodesStockModel.md)
 - [GPU](docs/GPU.md)
 - [GPUFields](docs/GPUFields.md)
 - [GPUList](docs/GPUList.md)
 - [GPURegionFields](docs/GPURegionFields.md)
 - [GenerateUpdateApiKeyPayload](docs/GenerateUpdateApiKeyPayload.md)
 - [GenerateUpdateApiKeyResponseModel](docs/GenerateUpdateApiKeyResponseModel.md)
 - [GetAllContractFields](docs/GetAllContractFields.md)
 - [GetAllContractsResponseModel](docs/GetAllContractsResponseModel.md)
 - [GetAllDiscountForAllOrganizationResponse](docs/GetAllDiscountForAllOrganizationResponse.md)
 - [GetAllDiscountsFields](docs/GetAllDiscountsFields.md)
 - [GetApiKeysResponseModel](docs/GetApiKeysResponseModel.md)
 - [GetCustomerContractsListResponseModel](docs/GetCustomerContractsListResponseModel.md)
 - [GetDiscountDetailResponse](docs/GetDiscountDetailResponse.md)
 - [GetDiscountResponse](docs/GetDiscountResponse.md)
 - [GetEntityDiscountDetailResponse](docs/GetEntityDiscountDetailResponse.md)
 - [GetInvitesResponseModel](docs/GetInvitesResponseModel.md)
 - [GetOrganizationResponseModel](docs/GetOrganizationResponseModel.md)
 - [GetPermissionsResponseModel](docs/GetPermissionsResponseModel.md)
 - [GetPoliciesResponseModel](docs/GetPoliciesResponseModel.md)
 - [GetRbacRolesResponseModel](docs/GetRbacRolesResponseModel.md)
 - [GetTokenPayload](docs/GetTokenPayload.md)
 - [GetUserPermissionsResponseModel](docs/GetUserPermissionsResponseModel.md)
 - [GetVersionResponse](docs/GetVersionResponse.md)
 - [Getcreditandthresholdinfo](docs/Getcreditandthresholdinfo.md)
 - [Getcreditandthresholdinfoinresponse](docs/Getcreditandthresholdinfoinresponse.md)
 - [GraphDatetimeValueModel](docs/GraphDatetimeValueModel.md)
 - [HistoricalInstance](docs/HistoricalInstance.md)
 - [HistoricalInstancesFields](docs/HistoricalInstancesFields.md)
 - [Image](docs/Image.md)
 - [ImageFields](docs/ImageFields.md)
 - [ImageGetResponse](docs/ImageGetResponse.md)
 - [ImageLogos](docs/ImageLogos.md)
 - [Images](docs/Images.md)
 - [ImportKeypairPayload](docs/ImportKeypairPayload.md)
 - [ImportKeypairResponse](docs/ImportKeypairResponse.md)
 - [InfrahubResourceObjectResponse](docs/InfrahubResourceObjectResponse.md)
 - [InfrahubResourceObjectResponseForCustomer](docs/InfrahubResourceObjectResponseForCustomer.md)
 - [InsertDiscountPlanFields](docs/InsertDiscountPlanFields.md)
 - [Instance](docs/Instance.md)
 - [InstanceEnvironmentFields](docs/InstanceEnvironmentFields.md)
 - [InstanceEvents](docs/InstanceEvents.md)
 - [InstanceEventsFields](docs/InstanceEventsFields.md)
 - [InstanceFields](docs/InstanceFields.md)
 - [InstanceFlavorFields](docs/InstanceFlavorFields.md)
 - [InstanceImageFields](docs/InstanceImageFields.md)
 - [InstanceKeypairFields](docs/InstanceKeypairFields.md)
 - [InstanceOverviewFields](docs/InstanceOverviewFields.md)
 - [InstanceResizePayload](docs/InstanceResizePayload.md)
 - [Instances](docs/Instances.md)
 - [InstancesSummaryFields](docs/InstancesSummaryFields.md)
 - [InternalEnvironmentFields](docs/InternalEnvironmentFields.md)
 - [InternalInstanceFields](docs/InternalInstanceFields.md)
 - [InternalInstanceFlavorFields](docs/InternalInstanceFlavorFields.md)
 - [InternalInstanceImageFields](docs/InternalInstanceImageFields.md)
 - [InternalInstanceKeypairFields](docs/InternalInstanceKeypairFields.md)
 - [InternalInstancesResponse](docs/InternalInstancesResponse.md)
 - [InternalSecurityRulesFieldsForInstance](docs/InternalSecurityRulesFieldsForInstance.md)
 - [InternalVolumeAttachmentFields](docs/InternalVolumeAttachmentFields.md)
 - [InternalVolumeFields](docs/InternalVolumeFields.md)
 - [InternalVolumesResponse](docs/InternalVolumesResponse.md)
 - [InviteFields](docs/InviteFields.md)
 - [InviteUserPayload](docs/InviteUserPayload.md)
 - [InviteUserResponseModel](docs/InviteUserResponseModel.md)
 - [KeypairFields](docs/KeypairFields.md)
 - [Keypairs](docs/Keypairs.md)
 - [LableResonse](docs/LableResonse.md)
 - [Lastdaycostfields](docs/Lastdaycostfields.md)
 - [Lastdaycostresponse](docs/Lastdaycostresponse.md)
 - [LogoGetResponse](docs/LogoGetResponse.md)
 - [LogoutPayload](docs/LogoutPayload.md)
 - [MetricItemFields](docs/MetricItemFields.md)
 - [MetricsFields](docs/MetricsFields.md)
 - [NameAvailableModel](docs/NameAvailableModel.md)
 - [NewConfigurationsResponse](docs/NewConfigurationsResponse.md)
 - [NewModelResponse](docs/NewModelResponse.md)
 - [NewStockResponse](docs/NewStockResponse.md)
 - [NewStockRetriveResponse](docs/NewStockRetriveResponse.md)
 - [NewStockUpdateResponseModel](docs/NewStockUpdateResponseModel.md)
 - [NodeModel](docs/NodeModel.md)
 - [NodePayloadModel](docs/NodePayloadModel.md)
 - [NodePowerUsageModel](docs/NodePowerUsageModel.md)
 - [NodeResponseModel](docs/NodeResponseModel.md)
 - [NodeStockPayloadModel](docs/NodeStockPayloadModel.md)
 - [NodeStockResponseModel](docs/NodeStockResponseModel.md)
 - [NodeStocksPayload](docs/NodeStocksPayload.md)
 - [OrganizationFields](docs/OrganizationFields.md)
 - [OrganizationLevelBillingHistory](docs/OrganizationLevelBillingHistory.md)
 - [OrganizationLevelBillingHistoryResources](docs/OrganizationLevelBillingHistoryResources.md)
 - [OrganizationLevelBillingHistoryResponseAttributes](docs/OrganizationLevelBillingHistoryResponseAttributes.md)
 - [OrganizationLevelBillingHistoryResponseMetrics](docs/OrganizationLevelBillingHistoryResponseMetrics.md)
 - [OrganizationLevelBillingHistoryResponseModel](docs/OrganizationLevelBillingHistoryResponseModel.md)
 - [OrganizationObjectResponse](docs/OrganizationObjectResponse.md)
 - [OrganizationThresholdfields](docs/OrganizationThresholdfields.md)
 - [OrganizationUserResponseModel](docs/OrganizationUserResponseModel.md)
 - [Organizationcreditrechargelimitresponse](docs/Organizationcreditrechargelimitresponse.md)
 - [Organizationthresholdsresponse](docs/Organizationthresholdsresponse.md)
 - [Organizationthresholdupdateresponse](docs/Organizationthresholdupdateresponse.md)
 - [OverviewInfo](docs/OverviewInfo.md)
 - [PaginationData](docs/PaginationData.md)
 - [PaymentDetailsFields](docs/PaymentDetailsFields.md)
 - [PaymentDetailsResponse](docs/PaymentDetailsResponse.md)
 - [PaymentInitiateFields](docs/PaymentInitiateFields.md)
 - [PaymentInitiatePayload](docs/PaymentInitiatePayload.md)
 - [PaymentInitiateResponse](docs/PaymentInitiateResponse.md)
 - [PermissionFields](docs/PermissionFields.md)
 - [PolicyFields](docs/PolicyFields.md)
 - [PolicyPermissionFields](docs/PolicyPermissionFields.md)
 - [PowerUsageModel](docs/PowerUsageModel.md)
 - [PricebookModel](docs/PricebookModel.md)
 - [PricebookResourceObjectResponse](docs/PricebookResourceObjectResponse.md)
 - [PricebookResourceObjectResponseForCustomer](docs/PricebookResourceObjectResponseForCustomer.md)
 - [ProfileFields](docs/ProfileFields.md)
 - [ProfileListResponse](docs/ProfileListResponse.md)
 - [ProfileObjectFields](docs/ProfileObjectFields.md)
 - [RbacRoleDetailResponseModel](docs/RbacRoleDetailResponseModel.md)
 - [RbacRoleDetailResponseModelFixed](docs/RbacRoleDetailResponseModelFixed.md)
 - [RbacRoleField](docs/RbacRoleField.md)
 - [RbacRoleFields](docs/RbacRoleFields.md)
 - [RefreshTokenPayload](docs/RefreshTokenPayload.md)
 - [RegionFields](docs/RegionFields.md)
 - [RegionPayload](docs/RegionPayload.md)
 - [RegionResponse](docs/RegionResponse.md)
 - [Regions](docs/Regions.md)
 - [RemoveMemberFromOrganizationResponseModel](docs/RemoveMemberFromOrganizationResponseModel.md)
 - [RemoveMemberPayload](docs/RemoveMemberPayload.md)
 - [RequestConsole](docs/RequestConsole.md)
 - [ResourceBillingEventsHistoryMetrics](docs/ResourceBillingEventsHistoryMetrics.md)
 - [ResourceBillingEventsHistoryResponse](docs/ResourceBillingEventsHistoryResponse.md)
 - [ResourceBillingResponseForCustomer](docs/ResourceBillingResponseForCustomer.md)
 - [ResourceLevelBillingDetailsAttributes](docs/ResourceLevelBillingDetailsAttributes.md)
 - [ResourceLevelBillingDetailsMetrics](docs/ResourceLevelBillingDetailsMetrics.md)
 - [ResourceLevelBillingDetailsVM](docs/ResourceLevelBillingDetailsVM.md)
 - [ResourceLevelBillingDetailsVolume](docs/ResourceLevelBillingDetailsVolume.md)
 - [ResourceLevelBillingDetailsVolumeAttributes](docs/ResourceLevelBillingDetailsVolumeAttributes.md)
 - [ResourceLevelBillingDetailsVolumeMetrics](docs/ResourceLevelBillingDetailsVolumeMetrics.md)
 - [ResourceLevelBillingHistory](docs/ResourceLevelBillingHistory.md)
 - [ResourceLevelBillingHistoryResources](docs/ResourceLevelBillingHistoryResources.md)
 - [ResourceLevelBillingHistoryResponseAttributes](docs/ResourceLevelBillingHistoryResponseAttributes.md)
 - [ResourceLevelBillingHistoryResponseMetrics](docs/ResourceLevelBillingHistoryResponseMetrics.md)
 - [ResourceLevelBillingVMDetailsResources](docs/ResourceLevelBillingVMDetailsResources.md)
 - [ResourceLevelBillingVolumeDetailsResources](docs/ResourceLevelBillingVolumeDetailsResources.md)
 - [ResourceLevelGraphBillingDetailVolume](docs/ResourceLevelGraphBillingDetailVolume.md)
 - [ResourceLevelGraphBillingDetailsAttributes](docs/ResourceLevelGraphBillingDetailsAttributes.md)
 - [ResourceLevelGraphBillingDetailsMetrics](docs/ResourceLevelGraphBillingDetailsMetrics.md)
 - [ResourceLevelGraphBillingDetailsVM](docs/ResourceLevelGraphBillingDetailsVM.md)
 - [ResourceLevelGraphBillingVMDetailsResources](docs/ResourceLevelGraphBillingVMDetailsResources.md)
 - [ResourceLevelGraphBillingVolumeDetailsResources](docs/ResourceLevelGraphBillingVolumeDetailsResources.md)
 - [ResourceLevelVMBillingDetailsResponseModel](docs/ResourceLevelVMBillingDetailsResponseModel.md)
 - [ResourceLevelVmBillingHistoryResponseModel](docs/ResourceLevelVmBillingHistoryResponseModel.md)
 - [ResourceLevelVmGraphBillingDetailsResponseModel](docs/ResourceLevelVmGraphBillingDetailsResponseModel.md)
 - [ResourceLevelVolumeBillingDetailsResponseModel](docs/ResourceLevelVolumeBillingDetailsResponseModel.md)
 - [ResourceLevelVolumeBillingHistoryResponseModel](docs/ResourceLevelVolumeBillingHistoryResponseModel.md)
 - [ResourceLevelVolumeGraphBillingDetailsResponseModel](docs/ResourceLevelVolumeGraphBillingDetailsResponseModel.md)
 - [ResourceObjectResponseForCustomer](docs/ResourceObjectResponseForCustomer.md)
 - [ResponseModel](docs/ResponseModel.md)
 - [RolePermissionFields](docs/RolePermissionFields.md)
 - [RolePolicyFields](docs/RolePolicyFields.md)
 - [SecurityGroupRule](docs/SecurityGroupRule.md)
 - [SecurityGroupRuleFields](docs/SecurityGroupRuleFields.md)
 - [SecurityRulesFieldsforInstance](docs/SecurityRulesFieldsforInstance.md)
 - [SecurityRulesProtocolFields](docs/SecurityRulesProtocolFields.md)
 - [SetDefaultsPayload](docs/SetDefaultsPayload.md)
 - [SingleVisibilityUserResponse](docs/SingleVisibilityUserResponse.md)
 - [SnapshotFields](docs/SnapshotFields.md)
 - [SnapshotRestoreRequest](docs/SnapshotRestoreRequest.md)
 - [SnapshotRetrieve](docs/SnapshotRetrieve.md)
 - [SnapshotRetrieveFields](docs/SnapshotRetrieveFields.md)
 - [Snapshots](docs/Snapshots.md)
 - [StartDeployment](docs/StartDeployment.md)
 - [StartDeploymentPayload](docs/StartDeploymentPayload.md)
 - [StockVisibilityUserListResponse](docs/StockVisibilityUserListResponse.md)
 - [StockVisibilityUserPayload](docs/StockVisibilityUserPayload.md)
 - [SubResourceGraphBillingDetailsMetrics](docs/SubResourceGraphBillingDetailsMetrics.md)
 - [SubResourcesCostsResponseModel](docs/SubResourcesCostsResponseModel.md)
 - [SubResourcesGraphBillingHistoryFields](docs/SubResourcesGraphBillingHistoryFields.md)
 - [SubResourcesGraphResponseModel](docs/SubResourcesGraphResponseModel.md)
 - [Subscribeorunsubscribeupdatepayload](docs/Subscribeorunsubscribeupdatepayload.md)
 - [SuccessResponseModel](docs/SuccessResponseModel.md)
 - [Template](docs/Template.md)
 - [TemplateFields](docs/TemplateFields.md)
 - [Templates](docs/Templates.md)
 - [TokenFields](docs/TokenFields.md)
 - [UpdateContractPayload](docs/UpdateContractPayload.md)
 - [UpdateDiscountsPayload](docs/UpdateDiscountsPayload.md)
 - [UpdateDiscountsStatusPayload](docs/UpdateDiscountsStatusPayload.md)
 - [UpdateEnvironment](docs/UpdateEnvironment.md)
 - [UpdateGPU](docs/UpdateGPU.md)
 - [UpdateKeypairName](docs/UpdateKeypairName.md)
 - [UpdateKeypairnameresponse](docs/UpdateKeypairnameresponse.md)
 - [UpdateOrganizationPayload](docs/UpdateOrganizationPayload.md)
 - [UpdateOrganizationResponseModel](docs/UpdateOrganizationResponseModel.md)
 - [UpdateTemplate](docs/UpdateTemplate.md)
 - [UserDefaultChoiceForUserFields](docs/UserDefaultChoiceForUserFields.md)
 - [UserDefaultChoicesForUserResponse](docs/UserDefaultChoicesForUserResponse.md)
 - [UserPermissionFields](docs/UserPermissionFields.md)
 - [UserTransferPayload](docs/UserTransferPayload.md)
 - [Userinfopostpayload](docs/Userinfopostpayload.md)
 - [UsersInfoFields](docs/UsersInfoFields.md)
 - [UsersInfoListResponse](docs/UsersInfoListResponse.md)
 - [VMUsageRequestPayload](docs/VMUsageRequestPayload.md)
 - [VMUsageResponse](docs/VMUsageResponse.md)
 - [VNCURL](docs/VNCURL.md)
 - [VNCURLFields](docs/VNCURLFields.md)
 - [VerifyApiKeyPayload](docs/VerifyApiKeyPayload.md)
 - [VerifyApiKeyResponseModel](docs/VerifyApiKeyResponseModel.md)
 - [VirtualMachineUsage](docs/VirtualMachineUsage.md)
 - [Volume](docs/Volume.md)
 - [VolumeAttachmentFields](docs/VolumeAttachmentFields.md)
 - [VolumeFields](docs/VolumeFields.md)
 - [VolumeFieldsforInstance](docs/VolumeFieldsforInstance.md)
 - [VolumeOverviewFields](docs/VolumeOverviewFields.md)
 - [VolumeStatusChangeFields](docs/VolumeStatusChangeFields.md)
 - [VolumeTypes](docs/VolumeTypes.md)
 - [Volumes](docs/Volumes.md)
 - [VolumesLastStatusChangeResponse](docs/VolumesLastStatusChangeResponse.md)
 - [WarningMailLogFields](docs/WarningMailLogFields.md)
 - [WarningMailLogResponse](docs/WarningMailLogResponse.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="accessToken"></a>
### accessToken

- **Type**: API key
- **API key parameter name**: Authorization
- **Location**: HTTP header

<a id="apiKey"></a>
### apiKey

- **Type**: API key
- **API key parameter name**: api_key
- **Location**: HTTP header


## Author




